# coding: utf-8

"""
    Weheat Backend

    This is the backend for the Weheat project

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class HeatPumpStatusEnum(int, Enum):
    """
    Last status of the heat pump from the last heat pump log   - Standby (40)   - Heating (70)   - Defrost (90)   - Cooling (130)   - DHW (150)   - Lionelle (160)   - SelfTest (170)  -  ManualControl (180)
    """

    """
    allowed enum values
    """
    NUMBER_40 = 40
    NUMBER_70 = 70
    NUMBER_90 = 90
    NUMBER_130 = 130
    NUMBER_150 = 150
    NUMBER_160 = 160
    NUMBER_170 = 170
    NUMBER_180 = 180

    @classmethod
    def from_json(cls, json_str: str) -> HeatPumpStatusEnum:
        """Create an instance of HeatPumpStatusEnum from a JSON string"""
        return HeatPumpStatusEnum(json.loads(json_str))


